FlatVec

Struct FlatVec 

pub struct FlatVec<T, IndexTy: Default, BackingTy, const INDEX_INLINE_LEN: usize> { /* private fields */ }
An indirection-collapsing container with minimal allocation

Read as “An internally-flattening Vec of T, indexed by IndexTy, where each T is stored as a slice of BackingTy” For simple use cases, you may want a type alias for FlatVec<T, usize, u8, 3>, but under some workloads it is very profitable to pick a smaller IndexTy, possibly even u8, and a corresponding inline capacity.

Implementations

Source

impl<'a, T: 'a, IndexTy, BackingTy, const INDEX_INLINE_LEN: usize> FlatVec<T, IndexTy, BackingTy, INDEX_INLINE_LEN>
where IndexTy: Default + TryFrom<usize> + Copy + Sub, usize: TryFrom<IndexTy>, <IndexTy as TryFrom<usize>>::Error: Debug, <usize as TryFrom<IndexTy>>::Error: Debug,

pub fn new() -> Self

Create a new FlatVec, this is just an alias for the Default implementation.

pub fn len(&self) -> usize

Returns the number of T in a FlatVec<T>.

pub fn data_len(&self) -> usize

Returns the number of BackingTy used to store the elements of a FlatVec. This does not necessarily correlate with storage used to store the indices.

pub fn data_capacity(&self) -> usize

pub fn is_empty(&self) -> bool

Returns true if the len is 0.

pub fn clear(&mut self)

pub fn push<Source>(&mut self, input: Source)
where Source: IntoFlat<BackingTy, T>,

Appends an element to the back of the collection.

pub fn get<Dest>(&'a self, index: usize) -> Option<Dest>
where Dest: FromFlat<'a, BackingTy, T> + 'a,

Construct a Dest from the indexth element’s stored representation.

pub fn iter<Dest>(&'a self) -> impl Iterator<Item = Dest> + 'a
where Dest: FromFlat<'a, BackingTy, T> + 'a,

Returns an iterator that constructs a Dest from each element’s stored representation.

Source

impl<'a, T: 'a, IndexTy, BackingTy, const INDEX_INLINE_LEN: usize> FlatVec<T, IndexTy, BackingTy, INDEX_INLINE_LEN>
where IndexTy: Default + TryFrom<usize> + Copy + Sub, usize: TryFrom<IndexTy>, <IndexTy as TryFrom<usize>>::Error: Debug, <usize as TryFrom<IndexTy>>::Error: Debug, BackingTy: Copy,

pub fn remove(&mut self, index: usize)

Removes the indexth element of a FlatVec. This function is O(self.len() + self.data_len()).