pub struct FlatVec<T, IndexTy: Default, BackingTy, const INDEX_INLINE_LEN: usize> { /* private fields */ }Expand description
An indirection-collapsing container with minimal allocation
Read as “An internally-flattening Vec of T, indexed by IndexTy, where each T is stored as a
slice of BackingTy”
For simple use cases, you may want a type alias for FlatVec<T, usize, u8, 3>, but under some
workloads it is very profitable to pick a smaller IndexTy, possibly even u8, and a
corresponding inline capacity.
Implementations
Sourceimpl<'a, T: 'a, IndexTy, BackingTy, const INDEX_INLINE_LEN: usize> FlatVec<T, IndexTy, BackingTy, INDEX_INLINE_LEN>
impl<'a, T: 'a, IndexTy, BackingTy, const INDEX_INLINE_LEN: usize> FlatVec<T, IndexTy, BackingTy, INDEX_INLINE_LEN>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new FlatVec, this is just an alias for the Default implementation.
Sourcepub fn data_len(&self) -> usize
pub fn data_len(&self) -> usize
Returns the number of BackingTy used to store the elements of a FlatVec. This does not
necessarily correlate with storage used to store the indices.
pub fn data_capacity(&self) -> usize
pub fn clear(&mut self)
Sourcepub fn push<Source>(&mut self, input: Source)where
Source: IntoFlat<BackingTy, T>,
pub fn push<Source>(&mut self, input: Source)where
Source: IntoFlat<BackingTy, T>,
Appends an element to the back of the collection.